# remirepo spec file for php-brotli
#
# Copyright (c) 2017-2021 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

# we don't want -z defs linker flag
%undefine _strict_symbol_defs_build

%if 0%{?scl:1}
%global sub_prefix  %{scl_prefix}
%scl_package        php-brotli
%else
%global pkg_name    %{name}
%endif

# To build with PHP 5.x use --without apcu
%bcond_without apcu

%if 0%{?fedora} >= 30 || 0%{?rhel} >= 7
%bcond_without      libbrotli
%else
%bcond_with         libbrotli
%endif

%global gh_commit   c17297688a6c7d23be33f170405f099aa7cd0d38
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    kjdev
%global gh_project  php-ext-brotli
#global gh_date     20160608
%global pecl_name   brotli
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini

Summary:       Brotli Extension for PHP
Name:          %{?sub_prefix}php-%{pecl_name}
Version:       0.13.1
%if 0%{?gh_date:1}
Release:       2%{gh_date}git%{gh_short}%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%else
Release:       1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%endif
License:       MIT
URL:           https://github.com/%{gh_owner}/%{gh_project}
Source0:       %{pkg_name}-%{version}-%{gh_short}.tgz
# retrieve a recursive git snapshot with submodule
Source1:       makesrc.sh

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
%if %{with apcu}
BuildRequires: %{?scl_prefix}php-devel > 7
BuildRequires: %{?scl_prefix}php-pecl-apcu-devel
%else
BuildRequires: %{?scl_prefix}php-devel
%endif
%if %{with libbrotli}
BuildRequires: brotli-devel >= 0.6.0
%else
Provides:      bundled(brotli) = 1.0.9
%endif

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
%if "%{php_version}" > "7.3"
Obsoletes:      php73-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:      php74-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "8.0"
Obsoletes:      php80-%{pecl_name} <= %{version}
%endif
%endif


%description
This extension allows Brotli compression.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc
mv %{gh_project}-%{gh_commit} NTS

cd NTS
# replace symlink
rm LICENSE
mv brotli/LICENSE .

%if %{with libbrotli}
# Use the system library
mv brotli tests
%endif

# Sanity check, really often broken
extver=$(sed -n '/#define BROTLI_EXT_VERSION/{s/.* "//;s/".*$//;p}' php_brotli.h)
if test "x${extver}" != "x%{version}%{?gh_date:-dev}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?gh_date:-dev}.
   exit 1
fi
cd ..

%if %{with_zts}
# duplicate for ZTS build
cp -pr NTS ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension = %{pecl_name}.so

; Configuration
;brotli.output_compression = 0
;brotli.output_compression_level = -1
EOF


%build
%{?dtsenable}

cd NTS
%if %{with libbrotli}
mv tests/brotli brotli
%endif
%{_bindir}/phpize
%configure \
    --with-php-config=%{_bindir}/php-config \
%if %{with libbrotli}
    --with-libbrotli \
%endif
    --with-libdir=%{_lib} \
    --enable-brotli
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%if %{with libbrotli}
mv tests/brotli brotli
%endif
%{_bindir}/zts-phpize
%configure \
    --with-php-config=%{_bindir}/zts-php-config \
%if %{with libbrotli}
    --with-libbrotli \
%endif
    --with-libdir=%{_lib} \
    --enable-brotli
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
# Install the ZTS stuff
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif



%check
cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if "%{php_version}" > "7.0"
: Check that apcu is aware of brotli serializer
%{__php} --no-php-ini \
    --define extension=apcu.so \
    --define apc.enabled=1 \
    --define apc.enable_cli=1 \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --ri apcu | grep '%{pecl_name}'
%endif

: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php  -q --offline --show-diff || : ignore

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php  -q --offline --show-diff
%endif


%files
%{!?_licensedir:%global license %%doc}
%license NTS/LICENSE
%doc NTS/README.md

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Sat Jan 23 2021 Remi Collet <remi@remirepo.net> - 0.13.1-1
- update to 0.13.1

* Fri Jan 22 2021 Remi Collet <remi@remirepo.net> - 0.13.0-1
- update to 0.13.0

* Fri Jan 15 2021 Remi Collet <remi@remirepo.net> - 0.12.0-1
- update to 0.12.0
- enable apcu serializer with PHP 7+

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 0.11.1-3
- rebuild for PHP 8.0.0RC1

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 0.11.1-2
- rebuild for PHP 8.0.0beta3

* Fri Aug 28 2020 Remi Collet <remi@remirepo.net> - 0.11.1-1
- update to 0.11.1

* Wed Aug  5 2020 Remi Collet <remi@remirepo.net> - 0.11.0-2
- rebuild for 8.0.0beta1

* Tue Aug  4 2020 Remi Collet <remi@remirepo.net> - 0.11.0-1
- update to 0.11.0

* Mon Jul 27 2020 Remi Collet <remi@remirepo.net> - 0.10.0-1
- update to 0.10.0

* Sat Jun 27 2020 Remi Collet <remi@remirepo.net> - 0.9.0-1
- update to 0.9.0

* Fri Jun  5 2020 Remi Collet <remi@remirepo.net> - 0.8.0-1
- update to 0.8.0
- drop patch merged upstream

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.7.0-4
- rebuild for 7.4.0RC1

* Wed Jul 24 2019 Remi Collet <remi@remirepo.net> - 0.7.0-3
- add patch for 7.4.0beta1 from
  https://github.com/kjdev/php-ext-brotli/pull/23

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 0.7.0-2
- rebuild for 7.4.0beta1

* Fri May  3 2019 Remi Collet <remi@remirepo.net> - 0.7.0-1
- update to 0.7.0

* Mon Jan  7 2019 Remi Collet <remi@remirepo.net> - 0.6.2-1
- update to 0.6.2

* Wed Nov 28 2018 Remi Collet <remi@remirepo.net> - 0.6.1-1
- update to 0.6.1 (no change)
- drop patches merged upstream

* Tue Nov 27 2018 Remi Collet <remi@remirepo.net> - 0.6.0-1
- update to 0.6.0, bundled libbrotli 1.0.7
- open https://github.com/kjdev/php-ext-brotli/pull/14 fix version
- open https://github.com/kjdev/php-ext-brotli/pull/15 fix skip
- open https://github.com/kjdev/php-ext-brotli/pull/16 comment

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.5.1-3
- rebuild for 7.3.0beta2 new ABI

* Tue Jul 17 2018 Remi Collet <remi@remirepo.net> - 0.5.1-2
- rebuld for 7.3.0alpha4 new ABI

* Mon Apr 16 2018 Remi Collet <remi@remirepo.net> - 0.5.1-1
- update to 0.5.1, bundled libbrotli 1.0.4
- open https://github.com/kjdev/php-ext-brotli/pull/9 fix version

* Thu Nov  9 2017 Remi Collet <remi@remirepo.net> - 0.5.0-1
- new package, version 0.5.0, bundled libbrotli 1.0.1
- add patch to build with system libbrotli
  open https://github.com/kjdev/php-ext-brotli/pull/6

